@@ -117,7 +117,7 @@ class I2AOauth2Client:
             raise I2AOauth2ClientException(data=response.json())
 
     def get_me(self, token):
-        url = self._get_full_url('me/')
+        url = self._get_full_url('application-users/me/')
         headers = self.headers.copy()
         headers['Authorization'] = f"Bearer {token}"
 
@@ -130,7 +130,7 @@ class I2AOauth2Client:
             raise I2AOauth2ClientException(data=response.json())
 
     def get_my_application_user(self, token):
-        url = self._get_full_url('my-application-user/')
+        url = self._get_full_url('application-users/my-application-user/')
         headers = self.headers.copy()
         headers['Authorization'] = f"Bearer {token}"
         response = requests.get(url, headers=headers)
